#
# spec file for package libvpl
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} < 1550
  %define _distconfdir %{_prefix}%{_sysconfdir}
%endif

%bcond_without tools

%global sover 2
Name:           libvpl
%define lname   libvpl%{sover}
Version:        2023.2.0
Release:        150600.2.2
Summary:        oneAPI Video Processing Library (oneVPL) dispatcher, tools, and examples
License:        MIT
Group:          Development/Languages/C and C++
URL:            https://github.com/oneapi-src/oneVPL
Source0:        https://github.com/oneapi-src/oneVPL/archive/refs/tags/v%{version}.tar.gz#/oneVPL-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(wayland-client)
%if 0%{?suse_version} > 1600
ExclusiveArch:  x86_64 %ix86
%else
ExclusiveArch:  x86_64
%endif

%description
The oneAPI Video Processing Library (oneVPL) provides a single video processing
API for encode, decode, and video processing that works across a wide range of
accelerators.

%package -n %lname
Summary:        oneAPI Video Processing Library (oneVPL) dispatcher
Group:          System/Libraries

%description -n %lname
The oneAPI Video Processing Library (oneVPL) provides a single video processing
API for encode, decode, and video processing that works across a wide range of
accelerators.

%package devel
Summary:        Development files for oneAPI Video Processing Library (oneVPL) dispatcher
Group:          Development/Languages/C and C++
Requires:       %lname = %version

%description devel
This package contains the development headers and pkgconfig files for
the oneAPI Video Processing Library (oneVPL) dispatcher

%package samples
Summary:        Examples for the oneAPI Video Processing Library (oneVPL) dispatcher
Group:          Development/Languages/C and C++

%description samples
This package contains example applications for the oneAPI Video Processing Library (oneVPL) dispatcher.

%prep
%autosetup -p1 -n oneVPL-%{version}

%build
%cmake \
  -DBUILD_TOOLS:BOOL=%{?with_tools:ON}%{!?with_tools:OFF} \
  %{nil}
%cmake_build

%install
%cmake_install

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%files
%doc README.md third-party-programs.txt

%files -n %lname
%license LICENSE
%dir %{_distconfdir}
%dir %{_distconfdir}/modulefiles
%dir %{_distconfdir}/vpl
%{_distconfdir}/modulefiles/vpl
%{_distconfdir}/vpl/vars.sh
%{_libdir}/libvpl.so.%{sover}
%{_libdir}/libvpl.so.%{sover}.*

%if %{with tools}
%files samples
%{_bindir}/*
%endif

%files devel
%doc
%{_includedir}/vpl/
%{_libdir}/libvpl.so
%{_libdir}/pkgconfig/vpl.pc
%{_libdir}/cmake/vpl/
%{_datadir}/vpl/

%changelog
* Wed Nov 29 2023 sndirsch@suse.com
- only build %%ix86 for Tumbleweed; otherwise just build it for
  x86_64 (bsc#1217662)
* Mon Apr 10 2023 stefan.bruens@rwth-aachen.de
- Update to version 2023.2.0
  * Added
    + oneVPL API 2.9 support
    + Perceptual encoding prefilter option to
    sample_multi_transcode
  * Fixed
    + VPP processing for YUV input
    + Sample_multi_transcode segfault on wayland
    + Missing prerequisites in vpl-infer README
  * Changed
    + vpl-infer Dockerfile and Linux setup steps to better align
    with https://dgpu-docs.intel.com/
  * Removed
    + dpcpp-blur example
- Drop upstreamed fix_arm_ilp32.patch
* Tue Jan 17 2023 stefan.bruens@rwth-aachen.de
- Update to version 2023.1.1
  * Added
    + Help screen listing valid options for vpl-inspect
    + YUV400 option for JPEG encoding with sample_encode
    + Build option --disable_experimental to build with
    ONEVPL_EXPERIMENTAL disabled
  * Changed
    + Session creation example to request a minimum API version
- Update to version 2023.1.0
  * Added
    + oneVPL API 2.8 support
    + New infer sample
    + xdg_shell for weston10
  * Fixed
    + NOT_ENOUGH_BUFFER error when HRD off in ExtBRC
    + Legacy tools using x86/x86_64 specific assembler code
    + Pkg-config files not installing in correct location in cross
    compilation scenarios
- Reenable other architectures again for all products.
  * Add fix_arm_ilp32.patch
- Drop upstream remove_x86_64_check.patch
* Tue Nov 15 2022 sndirsch@suse.com
- missed part of specfile to limit build to x86_64 on older
  products than factory
* Tue Nov  8 2022 sndirsch@suse.com
- limit build again to x86_64 on older products than factory
* Mon Nov  7 2022 sndirsch@suse.com
- needed for jira#PED-1174 (Video decoding/encoding support
  (VA-API, ...) for Intel GPUs is outside of Mesa)
* Wed Nov  2 2022 sndirsch@suse.com
- Update to version 2023.0.0
  * new bump from master branch
* Sat Sep 24 2022 stefan.bruens@rwth-aachen.de
- Update to version 2022.2.4
  * Add SMPTE ST 2084A color description preset
  * Add parallel encoding support
  * Add dynamic bitstream buffer reallocation
* Mon Sep 19 2022 stefan.bruens@rwth-aachen.de
- Update to version 2022.2.3
  * Multiple hardware adapters are supported as part of the 2.6
    API update. They provide faster performance by taking advantage
    of available platform resources.
  * MPEG2 decode is now supported in a CPU implementation to
    improve codec coverage for systems that do not have dedicated
    hardware.
* Mon Sep 19 2022 stefan.bruens@rwth-aachen.de
- Enable build on all archs, oneVPL is platform agnostic, add
  remove_x86_64_check.patch
* Mon Jul 11 2022 sndirsch@suse.com
- Update to version 2022.1.5
  * oneVPL 2022.1.0 has been updated to include functional and
    security updates.
  * part of oneVPL GPU Runtime 2022Q2 Release - 22.4.4
- third-party-programs.txt issue has been fixed; license.txt removed
  as well
- examples moved to /usr/share/vpl
- packaged new config scripts /usr/etc/modulefiles/vpl and
  /usr/etc/vpl/vars.sh
* Tue Nov  2 2021 sndirsch@suse.com
- remove third-party-programs.txt during setup
  * When not building on Windows using Visual Studio, the Visual
    Studio runtimes are not needed to be installed so we can remove
    these licenses from being mentioned. On Linux we're using
    cmake/make/gcc for building/installation and we don't have any
    (need for) MS Visual Studio runtime. (oneapi-src/oneVPL issue#27)
  - -> https://github.com/oneapi-src/oneVPL/issues/27
* Mon Oct  4 2021 sndirsch@suse.com
- fixed JIRA number in previous changelog
* Thu Sep 23 2021 sndirsch@suse.com
- created package libvpl (jira#SLE/SLE-19361)
  * oneAPI Video Processing Library (oneVPL) dispatcher, tools, and
    examples: The oneAPI Video Processing Library (oneVPL) provides
    a single video processing API for encode, decode, and video
    processing that works across a wide range of accelerators.
